@@ -1,5 +1,5 @@
 package Perl::MinimumVersion;
-$Perl::MinimumVersion::VERSION = '1.35';
+$Perl::MinimumVersion::VERSION = '1.36';
 =pod
 
 =head1 NAME
@@ -59,6 +59,8 @@ BEGIN {
 
 	# The primary list of version checks
 	%CHECKS = (
+        _stacked_labels         => version->new('5.014'),
+
 		_yada_yada_yada         => version->new('5.012'),
 		_pkg_name_version       => version->new('5.012'),
 		_postfix_when           => version->new('5.012'),
@@ -113,6 +115,7 @@ BEGIN {
 	);
 	@CHECKS_RV = ( #subs that return version
 	    '_feature_bundle','_regex','_each_argument','_binmode_2_arg',
+        '_scheduled_blocks',
 	);
 
 	# Predefine some indexes needed by various check methods
@@ -604,6 +607,35 @@ sub _feature_bundle {
 	return (defined($version)?"$version.0":undef, $obj);
 }
 
+my %SCHEDULED_BLOCK =
+(
+    'INIT'      => '5.006',
+    'CHECK'     => '5.006002',
+    'UNITCHECK' => '5.010',
+);
+
+sub _scheduled_blocks
+{
+    my @versions;
+    my ($version, $obj);
+
+	shift->Document->find( sub {
+		$_[1]->isa('PPI::Statement::Scheduled') or return '';
+        ($_[1]->children)[0]->isa('PPI::Token::Word') or return '';
+        my $function = (($_[1]->children)[0])->content;
+        exists( $SCHEDULED_BLOCK{ $function }) or return '';
+
+        my $v = $SCHEDULED_BLOCK{ ($_[1]->children)[0]->content };
+        if ($v and $v > ($version || 0) ) {
+            $version = $v;
+            $obj = $_[1];
+        }
+
+		return '';
+	} );
+	return (defined($version) ? $version : undef, $obj);
+}
+
 sub _regex {
     my @versions;
     my ($version, $obj);
@@ -869,6 +901,22 @@ sub _state_declaration {
 	} );
 }
 
+sub _stacked_labels {
+	shift->Document->find_first( sub {
+		$_[1]->isa('PPI::Statement::Compound') || return '';
+		$_[1]->schild(0)->isa('PPI::Token::Label') || return '';
+
+		my $next = $_[1]->snext_sibling || return '';
+
+        if (   $next->isa('PPI::Statement::Compound')
+            && $next->schild(0)->isa('PPI::Token::Label')) {
+            return 1;
+        }
+
+        0;
+    } );
+}
+
 sub _internals_svreadonly {
 	shift->Document->find_first( sub {
 		$_[1]->isa('PPI::Statement')
